import request from "@/utils/request";

const ConstitutionAPI = {
  /**
   * 获取体质类型
   *
   * @returns 体质类型列表
   */
  getConstitutionTypes(): Promise<ConstitutionTypeListResult> {
    return request<ConstitutionTypeListResult>({
      url: "/api/v1/health/constitution/types",
      method: "GET",
    });
  },

  /**
   * 获取体质测试题目
   *
   * @returns 测试题目列表
   */
  getConstitutionQuestions(): Promise<ConstitutionQuestionListResult> {
    return request<ConstitutionQuestionListResult>({
      url: "/api/v1/health/constitution/questions",
      method: "GET",
    });
  },

  /**
   * 提交体质测试
   *
   * @param data 测试答案
   * @returns 测试结果
   */
  submitConstitutionTest(data: ConstitutionTestData): Promise<ConstitutionTestResult> {
    return request<ConstitutionTestResult>({
      url: "/api/v1/health/constitution/test",
      method: "POST",
      data: data,
      header: {
        "Content-Type": "application/json",
      },
    });
  },

  /**
   * 获取体质测试历史
   *
   * @returns 测试历史列表
   */
  getConstitutionTestHistory(): Promise<ConstitutionTestHistoryResult> {
    return request<ConstitutionTestHistoryResult>({
      url: "/api/v1/health/constitution/test/history",
      method: "GET",
    });
  },

  /**
   * 获取体质建议
   *
   * @param constitutionType 体质类型
   * @returns 体质建议
   */
  getConstitutionAdvice(constitutionType: string): Promise<ConstitutionAdviceResult> {
    return request<ConstitutionAdviceResult>({
      url: `/api/v1/health/constitution/advice/${constitutionType}`,
      method: "GET",
    });
  },
};

export default ConstitutionAPI;

/** 体质类型列表响应 */
export interface ConstitutionTypeListResult {
  list: ConstitutionType[];
}

/** 体质类型 */
export interface ConstitutionType {
  id: string;
  name: string;
  description: string;
  characteristics: string[];
  healthRisks: string[];
  dietAdvice: string[];
  exerciseAdvice: string[];
  lifestyleAdvice: string[];
}

/** 体质测试题目列表响应 */
export interface ConstitutionQuestionListResult {
  list: ConstitutionQuestion[];
}

/** 体质测试题目 */
export interface ConstitutionQuestion {
  id: string;
  question: string;
  options: ConstitutionOption[];
  category: string;
}

/** 体质测试选项 */
export interface ConstitutionOption {
  id: string;
  text: string;
  score: number;
  constitutionType: string;
}

/** 体质测试数据 */
export interface ConstitutionTestData {
  answers: Record<string, string>;
}

/** 体质测试响应 */
export interface ConstitutionTestResult {
  test: ConstitutionTest;
}

/** 体质测试 */
export interface ConstitutionTest {
  id: string;
  userId: string;
  questions: ConstitutionQuestion[];
  result: ConstitutionResult;
  testDate: string;
}

/** 体质测试结果 */
export interface ConstitutionResult {
  primaryType: string;
  secondaryType?: string;
  scores: Record<string, number>;
  recommendations: ConstitutionRecommendation[];
}

/** 体质建议 */
export interface ConstitutionRecommendation {
  category: "diet" | "exercise" | "lifestyle" | "emotion";
  title: string;
  content: string;
  priority: "high" | "medium" | "low";
}

/** 体质测试历史响应 */
export interface ConstitutionTestHistoryResult {
  list: ConstitutionTest[];
}

/** 体质建议响应 */
export interface ConstitutionAdviceResult {
  advice: ConstitutionAdvice;
}

/** 体质建议详情 */
export interface ConstitutionAdvice {
  constitutionType: ConstitutionType;
  recommendations: ConstitutionRecommendation[];
  dietPlan: string[];
  exercisePlan: string[];
  lifestyleTips: string[];
}
