import request from "@/utils/request";

const ConsultationAPI = {
  /**
   * 获取医生列表
   *
   * @param params 查询参数
   * @returns 医生列表
   */
  getDoctors(params: DoctorQueryParams): Promise<DoctorListResult> {
    return request<DoctorListResult>({
      url: "/api/v1/health/consultation/doctors",
      method: "GET",
      data: params,
    });
  },

  /**
   * 获取医生详情
   *
   * @param doctorId 医生ID
   * @returns 医生详情
   */
  getDoctorDetail(doctorId: string): Promise<DoctorDetailResult> {
    return request<DoctorDetailResult>({
      url: `/api/v1/health/consultation/doctors/${doctorId}`,
      method: "GET",
    });
  },

  /**
   * 创建咨询
   *
   * @param data 咨询数据
   * @returns 咨询信息
   */
  createConsultation(data: CreateConsultationData): Promise<ConsultationResult> {
    return request<ConsultationResult>({
      url: "/api/v1/health/consultation/create",
      method: "POST",
      data: data,
      header: {
        "Content-Type": "application/json",
      },
    });
  },

  /**
   * 获取咨询历史
   *
   * @param params 查询参数
   * @returns 咨询历史列表
   */
  getConsultationHistory(params: ConsultationQueryParams): Promise<ConsultationListResult> {
    return request<ConsultationListResult>({
      url: "/api/v1/health/consultation/history",
      method: "GET",
      data: params,
    });
  },

  /**
   * 获取咨询详情
   *
   * @param consultationId 咨询ID
   * @returns 咨询详情
   */
  getConsultationDetail(consultationId: string): Promise<ConsultationDetailResult> {
    return request<ConsultationDetailResult>({
      url: `/api/v1/health/consultation/${consultationId}`,
      method: "GET",
    });
  },

  /**
   * 发送消息
   *
   * @param data 消息数据
   * @returns 消息信息
   */
  sendMessage(data: SendMessageData): Promise<MessageResult> {
    return request<MessageResult>({
      url: "/api/v1/health/consultation/message",
      method: "POST",
      data: data,
      header: {
        "Content-Type": "application/json",
      },
    });
  },

  /**
   * 获取聊天记录
   *
   * @param consultationId 咨询ID
   * @param params 查询参数
   * @returns 聊天记录列表
   */
  getChatMessages(consultationId: string, params: MessageQueryParams): Promise<MessageListResult> {
    return request<MessageListResult>({
      url: `/api/v1/health/consultation/${consultationId}/messages`,
      method: "GET",
      data: params,
    });
  },

  /**
   * 结束咨询
   *
   * @param consultationId 咨询ID
   */
  endConsultation(consultationId: string): Promise<void> {
    return request({
      url: `/api/v1/health/consultation/${consultationId}/end`,
      method: "POST",
    });
  },

  /**
   * 评价咨询
   *
   * @param consultationId 咨询ID
   * @param data 评价数据
   */
  rateConsultation(consultationId: string, data: RateConsultationData): Promise<void> {
    return request({
      url: `/api/v1/health/consultation/${consultationId}/rate`,
      method: "POST",
      data: data,
      header: {
        "Content-Type": "application/json",
      },
    });
  },
};

export default ConsultationAPI;

/** 医生查询参数 */
export interface DoctorQueryParams {
  specialty?: string;
  isOnline?: boolean;
  page: number;
  pageSize: number;
}

/** 医生列表响应 */
export interface DoctorListResult {
  list: Doctor[];
  total: number;
  page: number;
  pageSize: number;
}

/** 医生详情响应 */
export interface DoctorDetailResult {
  doctor: Doctor;
}

/** 医生信息 */
export interface Doctor {
  id: string;
  name: string;
  avatar: string;
  title: string;
  department: string;
  hospital: string;
  experience: number;
  rating: number;
  consultationFee: number;
  isOnline: boolean;
  specialty: string[];
  introduction: string;
}

/** 创建咨询数据 */
export interface CreateConsultationData {
  doctorId: string;
  type: "text" | "voice" | "video";
  symptoms: string;
}

/** 咨询响应 */
export interface ConsultationResult {
  consultation: Consultation;
}

/** 咨询信息 */
export interface Consultation {
  id: string;
  doctorId: string;
  patientId: string;
  type: "text" | "voice" | "video";
  status: "pending" | "ongoing" | "completed" | "cancelled";
  symptoms: string;
  diagnosis?: string;
  prescription?: Prescription[];
  startTime: string;
  endTime?: string;
  fee: number;
  rating?: number;
  review?: string;
}

/** 处方信息 */
export interface Prescription {
  id: string;
  medicineId: string;
  medicineName: string;
  dosage: string;
  frequency: string;
  duration: string;
  notes?: string;
}

/** 咨询查询参数 */
export interface ConsultationQueryParams {
  page: number;
  pageSize: number;
}

/** 咨询列表响应 */
export interface ConsultationListResult {
  list: Consultation[];
  total: number;
  page: number;
  pageSize: number;
}

/** 咨询详情响应 */
export interface ConsultationDetailResult {
  consultation: Consultation;
}

/** 发送消息数据 */
export interface SendMessageData {
  consultationId: string;
  type: "text" | "image" | "voice" | "video" | "prescription";
  content: string;
}

/** 消息响应 */
export interface MessageResult {
  message: ChatMessage;
}

/** 聊天消息 */
export interface ChatMessage {
  id: string;
  consultationId: string;
  senderId: string;
  senderType: "doctor" | "patient";
  type: "text" | "image" | "voice" | "video" | "prescription";
  content: string;
  timestamp: string;
  isRead: boolean;
}

/** 消息查询参数 */
export interface MessageQueryParams {
  page: number;
  pageSize: number;
}

/** 消息列表响应 */
export interface MessageListResult {
  list: ChatMessage[];
  total: number;
  page: number;
  pageSize: number;
}

/** 评价咨询数据 */
export interface RateConsultationData {
  rating: number;
  review: string;
}
