import request from "@/utils/request";

const DetectionAPI = {
  /**
   * 记录生命体征
   *
   * @param data 生命体征数据
   * @returns 记录结果
   */
  recordVitalSigns(data: VitalSignsData): Promise<VitalSignsResult> {
    return request<VitalSignsResult>({
      url: "/api/v1/health/detection/vitals",
      method: "POST",
      data: data,
      header: {
        "Content-Type": "application/json",
      },
    });
  },

  /**
   * 获取生命体征历史
   *
   * @param params 查询参数
   * @returns 生命体征历史列表
   */
  getVitalSignsHistory(params: VitalSignsQueryParams): Promise<VitalSignsListResult> {
    return request<VitalSignsListResult>({
      url: "/api/v1/health/detection/vitals/history",
      method: "GET",
      data: params,
    });
  },

  /**
   * 生成健康报告
   *
   * @param data 报告类型
   * @returns 健康报告
   */
  generateHealthReport(data: GenerateReportData): Promise<HealthReportResult> {
    return request<HealthReportResult>({
      url: "/api/v1/health/detection/report/generate",
      method: "POST",
      data: data,
      header: {
        "Content-Type": "application/json",
      },
    });
  },

  /**
   * 获取健康报告
   *
   * @param params 查询参数
   * @returns 健康报告列表
   */
  getHealthReports(params: ReportQueryParams): Promise<HealthReportListResult> {
    return request<HealthReportListResult>({
      url: "/api/v1/health/detection/reports",
      method: "GET",
      data: params,
    });
  },

  /**
   * 获取健康报告详情
   *
   * @param reportId 报告ID
   * @returns 健康报告详情
   */
  getHealthReportDetail(reportId: string): Promise<HealthReportDetailResult> {
    return request<HealthReportDetailResult>({
      url: `/api/v1/health/detection/reports/${reportId}`,
      method: "GET",
    });
  },

  /**
   * 获取健康趋势
   *
   * @param params 查询参数
   * @returns 健康趋势数据
   */
  getHealthTrends(params: TrendQueryParams): Promise<HealthTrendResult> {
    return request<HealthTrendResult>({
      url: "/api/v1/health/detection/trends",
      method: "GET",
      data: params,
    });
  },
};

export default DetectionAPI;

/** 生命体征数据 */
export interface VitalSignsData {
  bloodPressure: {
    systolic: number;
    diastolic: number;
  };
  heartRate: number;
  bodyTemperature: number;
  bloodOxygen: number;
  bloodGlucose: number;
  weight: number;
  height: number;
  steps: number;
  deviceId?: string;
}

/** 生命体征响应 */
export interface VitalSignsResult {
  vitalSigns: VitalSigns;
}

/** 生命体征信息 */
export interface VitalSigns {
  id: string;
  userId: string;
  bloodPressure: {
    systolic: number;
    diastolic: number;
  };
  heartRate: number;
  bodyTemperature: number;
  bloodOxygen: number;
  weight: number;
  height: number;
  bmi: number;
  recordTime: string;
  deviceId?: string;
}

/** 生命体征查询参数 */
export interface VitalSignsQueryParams {
  startDate?: string;
  endDate?: string;
  page: number;
  pageSize: number;
}

/** 生命体征列表响应 */
export interface VitalSignsListResult {
  list: VitalSigns[];
  total: number;
  page: number;
  pageSize: number;
}

/** 生成报告数据 */
export interface GenerateReportData {
  type: "basic" | "comprehensive" | "specialized";
}

/** 健康报告响应 */
export interface HealthReportResult {
  report: HealthReport;
}

/** 健康报告信息 */
export interface HealthReport {
  id: string;
  userId: string;
  type: "basic" | "comprehensive" | "specialized";
  indicators: HealthIndicator[];
  overallScore: number;
  riskLevel: "low" | "medium" | "high";
  suggestions: string[];
  reportDate: string;
  nextCheckDate?: string;
}

/** 健康指标 */
export interface HealthIndicator {
  name: string;
  value: number;
  unit: string;
  normalRange: [number, number];
  status: "normal" | "warning" | "abnormal";
  trend: "up" | "down" | "stable";
}

/** 报告查询参数 */
export interface ReportQueryParams {
  page: number;
  pageSize: number;
}

/** 健康报告列表响应 */
export interface HealthReportListResult {
  list: HealthReport[];
  total: number;
  page: number;
  pageSize: number;
}

/** 健康报告详情响应 */
export interface HealthReportDetailResult {
  report: HealthReport;
}

/** 趋势查询参数 */
export interface TrendQueryParams {
  indicator: string;
  period: "7d" | "30d" | "90d" | "1y";
}

/** 健康趋势响应 */
export interface HealthTrendResult {
  trends: HealthIndicator[];
}
