import request from "@/utils/request";

const DietAPI = {
  /**
   * 搜索食物
   *
   * @param keyword 关键词
   * @param params 查询参数
   * @returns 食物列表
   */
  searchFoods(keyword: string, params: FoodQueryParams): Promise<FoodListResult> {
    return request<FoodListResult>({
      url: "/api/v1/health/diet/foods/search",
      method: "GET",
      data: { keyword, ...params },
    });
  },

  /**
   * 获取食物详情
   *
   * @param foodId 食物ID
   * @returns 食物详情
   */
  getFoodDetail(foodId: string): Promise<FoodDetailResult> {
    return request<FoodDetailResult>({
      url: `/api/v1/health/diet/foods/${foodId}`,
      method: "GET",
    });
  },

  /**
   * 记录用餐
   *
   * @param data 用餐数据
   * @returns 用餐记录
   */
  recordMeal(data: MealRecordData): Promise<MealRecordResult> {
    return request<MealRecordResult>({
      url: "/api/v1/health/diet/meals",
      method: "POST",
      data: data,
      header: {
        "Content-Type": "application/json",
      },
    });
  },

  /**
   * 获取用餐记录
   *
   * @param params 查询参数
   * @returns 用餐记录列表
   */
  getMealRecords(params: MealRecordQueryParams): Promise<MealRecordListResult> {
    return request<MealRecordListResult>({
      url: "/api/v1/health/diet/meals/history",
      method: "GET",
      data: params,
    });
  },

  /**
   * 获取营养分析
   *
   * @param params 查询参数
   * @returns 营养分析结果
   */
  getNutritionAnalysis(params: NutritionAnalysisParams): Promise<NutritionAnalysisResult> {
    return request<NutritionAnalysisResult>({
      url: "/api/v1/health/diet/nutrition/analysis",
      method: "GET",
      data: params,
    });
  },

  /**
   * 获取膳食计划
   *
   * @returns 膳食计划列表
   */
  getDietPlans(): Promise<DietPlanListResult> {
    return request<DietPlanListResult>({
      url: "/api/v1/health/diet/plans",
      method: "GET",
    });
  },

  /**
   * 创建膳食计划
   *
   * @param data 膳食计划数据
   * @returns 膳食计划
   */
  createDietPlan(data: DietPlanData): Promise<DietPlanResult> {
    return request<DietPlanResult>({
      url: "/api/v1/health/diet/plans",
      method: "POST",
      data: data,
      header: {
        "Content-Type": "application/json",
      },
    });
  },

  /**
   * 激活膳食计划
   *
   * @param planId 计划ID
   */
  activateDietPlan(planId: string): Promise<void> {
    return request({
      url: `/api/v1/health/diet/plans/${planId}/activate`,
      method: "POST",
    });
  },

  /**
   * 获取推荐食谱
   *
   * @param params 查询参数
   * @returns 推荐食谱列表
   */
  getRecommendedRecipes(params: RecipeQueryParams): Promise<RecipeListResult> {
    return request<RecipeListResult>({
      url: "/api/v1/health/diet/recipes/recommend",
      method: "GET",
      data: params,
    });
  },
};

export default DietAPI;

/** 食物查询参数 */
export interface FoodQueryParams {
  page: number;
  pageSize: number;
}

/** 食物列表响应 */
export interface FoodListResult {
  list: Food[];
  total: number;
  page: number;
  pageSize: number;
}

/** 食物详情响应 */
export interface FoodDetailResult {
  food: Food;
}

/** 食物信息 */
export interface Food {
  id: string;
  name: string;
  category: string;
  calories: number;
  nutrients: Nutrients;
  glycemicIndex?: number;
  allergens?: string[];
}

/** 营养成分 */
export interface Nutrients {
  protein: number;
  carbohydrates: number;
  fat: number;
  fiber: number;
  sodium: number;
  vitamins: Record<string, number>;
  minerals: Record<string, number>;
}

/** 用餐记录数据 */
export interface MealRecordData {
  mealType: "breakfast" | "lunch" | "dinner" | "snack";
  foods: FoodItemData[];
  recordTime: string;
  images?: string[];
}

/** 食物项目数据 */
export interface FoodItemData {
  foodId: string;
  foodName: string;
  quantity: number;
}

/** 用餐记录 */
export interface MealRecord {
  id: string;
  userId: string;
  mealType: "breakfast" | "lunch" | "dinner" | "snack";
  foods: FoodItem[];
  totalCalories: number;
  totalNutrients: Nutrients;
  recordTime: string;
  images?: string[];
}

/** 食物项目 */
export interface FoodItem {
  foodId: string;
  foodName: string;
  quantity: number;
  calories: number;
  nutrients: Nutrients;
}

/** 用餐记录响应 */
export interface MealRecordResult {
  record: MealRecord;
}

/** 用餐记录查询参数 */
export interface MealRecordQueryParams {
  date?: string;
  mealType?: string;
  page: number;
  pageSize: number;
}

/** 用餐记录列表响应 */
export interface MealRecordListResult {
  list: MealRecord[];
  total: number;
  page: number;
  pageSize: number;
}

/** 营养分析参数 */
export interface NutritionAnalysisParams {
  startDate: string;
  endDate: string;
}

/** 营养分析响应 */
export interface NutritionAnalysisResult {
  analysis: NutritionAnalysis;
}

/** 营养分析 */
export interface NutritionAnalysis {
  totalCalories: number;
  averageCalories: number;
  totalNutrients: Nutrients;
  dailyGoals: Nutrients;
  achievements: Record<string, number>;
  suggestions: string[];
}

/** 膳食计划数据 */
export interface DietPlanData {
  name: string;
  type: "weight_loss" | "weight_gain" | "maintenance" | "diabetic" | "hypertension";
  targetCalories: number;
  targetNutrients: Nutrients;
  duration: number;
  meals: PlannedMealData[];
}

/** 计划用餐数据 */
export interface PlannedMealData {
  mealType: "breakfast" | "lunch" | "dinner" | "snack";
  foods: FoodItemData[];
  targetCalories: number;
  instructions?: string;
}

/** 膳食计划 */
export interface DietPlan {
  id: string;
  userId: string;
  name: string;
  type: "weight_loss" | "weight_gain" | "maintenance" | "diabetic" | "hypertension";
  targetCalories: number;
  targetNutrients: Nutrients;
  duration: number;
  meals: PlannedMeal[];
  createdDate: string;
  isActive: boolean;
}

/** 计划用餐 */
export interface PlannedMeal {
  mealType: "breakfast" | "lunch" | "dinner" | "snack";
  foods: FoodItem[];
  targetCalories: number;
  instructions?: string;
}

/** 膳食计划列表响应 */
export interface DietPlanListResult {
  list: DietPlan[];
}

/** 膳食计划响应 */
export interface DietPlanResult {
  plan: DietPlan;
}

/** 食谱查询参数 */
export interface RecipeQueryParams {
  mealType: string;
  calories?: number;
  dietType?: string;
}

/** 食谱列表响应 */
export interface RecipeListResult {
  list: Recipe[];
}

/** 食谱信息 */
export interface Recipe {
  id: string;
  name: string;
  description: string;
  mealType: string;
  calories: number;
  nutrients: Nutrients;
  ingredients: string[];
  instructions: string[];
  images: string[];
  cookingTime: number;
  difficulty: "easy" | "medium" | "hard";
}
