import request from "@/utils/request";

const EncyclopediaAPI = {
  /**
   * 获取分类列表
   *
   * @returns 分类列表
   */
  getCategories(): Promise<CategoryListResult> {
    return request<CategoryListResult>({
      url: "/api/v1/health/encyclopedia/categories",
      method: "GET",
    });
  },

  /**
   * 搜索中药
   *
   * @param keyword 关键词
   * @param params 查询参数
   * @returns 中药列表
   */
  searchHerbs(keyword: string, params: HerbQueryParams): Promise<HerbListResult> {
    return request<HerbListResult>({
      url: "/api/v1/health/encyclopedia/herbs/search",
      method: "GET",
      data: { keyword, ...params },
    });
  },

  /**
   * 获取中药详情
   *
   * @param herbId 中药ID
   * @returns 中药详情
   */
  getHerbDetail(herbId: string): Promise<HerbDetailResult> {
    return request<HerbDetailResult>({
      url: `/api/v1/health/encyclopedia/herbs/${herbId}`,
      method: "GET",
    });
  },

  /**
   * 获取中药列表
   *
   * @param params 查询参数
   * @returns 中药列表
   */
  getHerbs(params: HerbFilterParams): Promise<HerbListResult> {
    return request<HerbListResult>({
      url: "/api/v1/health/encyclopedia/herbs",
      method: "GET",
      data: params,
    });
  },

  /**
   * 搜索穴位
   *
   * @param keyword 关键词
   * @param params 查询参数
   * @returns 穴位列表
   */
  searchAcupoints(keyword: string, params: AcupointQueryParams): Promise<AcupointListResult> {
    return request<AcupointListResult>({
      url: "/api/v1/health/encyclopedia/acupoints/search",
      method: "GET",
      data: { keyword, ...params },
    });
  },

  /**
   * 获取穴位详情
   *
   * @param acupointId 穴位ID
   * @returns 穴位详情
   */
  getAcupointDetail(acupointId: string): Promise<AcupointDetailResult> {
    return request<AcupointDetailResult>({
      url: `/api/v1/health/encyclopedia/acupoints/${acupointId}`,
      method: "GET",
    });
  },

  /**
   * 获取穴位列表
   *
   * @param params 查询参数
   * @returns 穴位列表
   */
  getAcupoints(params: AcupointFilterParams): Promise<AcupointListResult> {
    return request<AcupointListResult>({
      url: "/api/v1/health/encyclopedia/acupoints",
      method: "GET",
      data: params,
    });
  },

  /**
   * 获取经络列表
   *
   * @returns 经络列表
   */
  getMeridians(): Promise<MeridianListResult> {
    return request<MeridianListResult>({
      url: "/api/v1/health/encyclopedia/meridians",
      method: "GET",
    });
  },

  /**
   * 获取经络详情
   *
   * @param meridianId 经络ID
   * @returns 经络详情
   */
  getMeridianDetail(meridianId: string): Promise<MeridianDetailResult> {
    return request<MeridianDetailResult>({
      url: `/api/v1/health/encyclopedia/meridians/${meridianId}`,
      method: "GET",
    });
  },
};

export default EncyclopediaAPI;

/** 分类列表响应 */
export interface CategoryListResult {
  list: EncyclopediaCategory[];
}

/** 百科分类 */
export interface EncyclopediaCategory {
  id: string;
  name: string;
  type: "herb" | "acupoint" | "meridian" | "theory";
  description: string;
  icon: string;
  itemCount: number;
}

/** 中药查询参数 */
export interface HerbQueryParams {
  page: number;
  pageSize: number;
}

/** 中药筛选参数 */
export interface HerbFilterParams {
  category?: string;
  nature?: string;
  meridian?: string;
  page: number;
  pageSize: number;
}

/** 中药列表响应 */
export interface HerbListResult {
  list: Herb[];
  total: number;
  page: number;
  pageSize: number;
}

/** 中药详情响应 */
export interface HerbDetailResult {
  herb: Herb;
}

/** 中药信息 */
export interface Herb {
  id: string;
  name: string;
  latinName?: string;
  aliases: string[];
  category: string;
  nature: "hot" | "warm" | "neutral" | "cool" | "cold";
  taste: string[];
  meridians: string[];
  effects: string[];
  indications: string[];
  contraindications: string[];
  dosage: string;
  preparations: string[];
  images: string[];
  description: string;
}

/** 穴位查询参数 */
export interface AcupointQueryParams {
  page: number;
  pageSize: number;
}

/** 穴位筛选参数 */
export interface AcupointFilterParams {
  meridian?: string;
  category?: string;
  page: number;
  pageSize: number;
}

/** 穴位列表响应 */
export interface AcupointListResult {
  list: Acupoint[];
  total: number;
  page: number;
  pageSize: number;
}

/** 穴位详情响应 */
export interface AcupointDetailResult {
  acupoint: Acupoint;
}

/** 穴位信息 */
export interface Acupoint {
  id: string;
  name: string;
  location: string;
  meridian: string;
  category: string;
  effects: string[];
  indications: string[];
  manipulations: string[];
  precautions: string[];
  images: string[];
  videos?: string[];
}

/** 经络列表响应 */
export interface MeridianListResult {
  list: Meridian[];
}

/** 经络详情响应 */
export interface MeridianDetailResult {
  meridian: Meridian;
}

/** 经络信息 */
export interface Meridian {
  id: string;
  name: string;
  type: "main" | "extraordinary";
  pathways: string[];
  acupoints: string[];
  functions: string[];
  associatedOrgans: string[];
  flowTime: string;
  images: string[];
}
