import request from "@/utils/request";

const ExerciseAPI = {
  /**
   * 获取运动列表
   *
   * @param params 查询参数
   * @returns 运动列表
   */
  getExercises(params: ExerciseQueryParams): Promise<ExerciseListResult> {
    return request<ExerciseListResult>({
      url: "/api/v1/health/exercise/exercises",
      method: "GET",
      data: params,
    });
  },

  /**
   * 获取运动详情
   *
   * @param exerciseId 运动ID
   * @returns 运动详情
   */
  getExerciseDetail(exerciseId: string): Promise<ExerciseDetailResult> {
    return request<ExerciseDetailResult>({
      url: `/api/v1/health/exercise/exercises/${exerciseId}`,
      method: "GET",
    });
  },

  /**
   * 记录运动
   *
   * @param data 运动数据
   * @returns 运动记录
   */
  recordExercise(data: ExerciseRecordData): Promise<ExerciseRecordResult> {
    return request<ExerciseRecordResult>({
      url: "/api/v1/health/exercise/records",
      method: "POST",
      data: data,
      header: {
        "Content-Type": "application/json",
      },
    });
  },

  /**
   * 获取运动记录
   *
   * @param params 查询参数
   * @returns 运动记录列表
   */
  getExerciseRecords(params: ExerciseRecordQueryParams): Promise<ExerciseRecordListResult> {
    return request<ExerciseRecordListResult>({
      url: "/api/v1/health/exercise/records/history",
      method: "GET",
      data: params,
    });
  },

  /**
   * 获取运动统计
   *
   * @param params 查询参数
   * @returns 运动统计数据
   */
  getExerciseStats(params: ExerciseStatsParams): Promise<ExerciseStatsResult> {
    return request<ExerciseStatsResult>({
      url: "/api/v1/health/exercise/stats",
      method: "GET",
      data: params,
    });
  },

  /**
   * 获取运动计划
   *
   * @returns 运动计划列表
   */
  getExercisePlans(): Promise<ExercisePlanListResult> {
    return request<ExercisePlanListResult>({
      url: "/api/v1/health/exercise/plans",
      method: "GET",
    });
  },

  /**
   * 创建运动计划
   *
   * @param data 运动计划数据
   * @returns 运动计划
   */
  createExercisePlan(data: ExercisePlanData): Promise<ExercisePlanResult> {
    return request<ExercisePlanResult>({
      url: "/api/v1/health/exercise/plans",
      method: "POST",
      data: data,
      header: {
        "Content-Type": "application/json",
      },
    });
  },

  /**
   * 激活运动计划
   *
   * @param planId 计划ID
   */
  activateExercisePlan(planId: string): Promise<void> {
    return request({
      url: `/api/v1/health/exercise/plans/${planId}/activate`,
      method: "POST",
    });
  },

  /**
   * 获取推荐运动
   *
   * @param params 查询参数
   * @returns 推荐运动列表
   */
  getRecommendedExercises(params: RecommendedExerciseParams): Promise<RecommendedExerciseResult> {
    return request<RecommendedExerciseResult>({
      url: "/api/v1/health/exercise/recommend",
      method: "GET",
      data: params,
    });
  },
};

export default ExerciseAPI;

/** 运动查询参数 */
export interface ExerciseQueryParams {
  category?: string;
  difficulty?: string;
  duration?: number;
  page: number;
  pageSize: number;
}

/** 运动列表响应 */
export interface ExerciseListResult {
  list: Exercise[];
  total: number;
  page: number;
  pageSize: number;
}

/** 运动详情响应 */
export interface ExerciseDetailResult {
  exercise: Exercise;
}

/** 运动信息 */
export interface Exercise {
  id: string;
  name: string;
  category: "cardio" | "strength" | "flexibility" | "balance" | "sports";
  difficulty: "beginner" | "intermediate" | "advanced";
  duration: number;
  caloriesPerMinute: number;
  equipment?: string[];
  instructions: string[];
  images?: string[];
  videos?: string[];
}

/** 运动记录数据 */
export interface ExerciseRecordData {
  exerciseId: string;
  exerciseName: string;
  duration: number;
  intensity: "low" | "medium" | "high";
  heartRate?: {
    average: number;
    maximum: number;
  };
  distance?: number;
  sets?: ExerciseSetData[];
  recordTime: string;
  notes?: string;
}

/** 运动组数据 */
export interface ExerciseSetData {
  reps: number;
  weight?: number;
  restTime?: number;
}

/** 运动记录 */
export interface ExerciseRecord {
  id: string;
  userId: string;
  exerciseId: string;
  exerciseName: string;
  duration: number;
  intensity: "low" | "medium" | "high";
  caloriesBurned: number;
  heartRate?: {
    average: number;
    maximum: number;
  };
  distance?: number;
  sets?: ExerciseSet[];
  recordTime: string;
  notes?: string;
}

/** 运动组 */
export interface ExerciseSet {
  reps: number;
  weight?: number;
  restTime?: number;
}

/** 运动记录响应 */
export interface ExerciseRecordResult {
  record: ExerciseRecord;
}

/** 运动记录查询参数 */
export interface ExerciseRecordQueryParams {
  startDate?: string;
  endDate?: string;
  page: number;
  pageSize: number;
}

/** 运动记录列表响应 */
export interface ExerciseRecordListResult {
  list: ExerciseRecord[];
  total: number;
  page: number;
  pageSize: number;
}

/** 运动统计参数 */
export interface ExerciseStatsParams {
  period: "7d" | "30d" | "90d" | "1y";
}

/** 运动统计响应 */
export interface ExerciseStatsResult {
  stats: ExerciseStats;
}

/** 运动统计 */
export interface ExerciseStats {
  totalDuration: number;
  totalCalories: number;
  totalWorkouts: number;
  averageDuration: number;
  averageCalories: number;
  categoryBreakdown: Record<string, number>;
  weeklyTrend: Array<{
    date: string;
    duration: number;
    calories: number;
  }>;
}

/** 运动计划数据 */
export interface ExercisePlanData {
  name: string;
  goal: "weight_loss" | "muscle_gain" | "endurance" | "strength" | "general_fitness";
  difficulty: "beginner" | "intermediate" | "advanced";
  duration: number;
  weeklySchedule: WeeklyScheduleData[];
}

/** 周计划数据 */
export interface WeeklyScheduleData {
  dayOfWeek: number;
  exercises: PlannedExerciseData[];
  restDay: boolean;
}

/** 计划运动数据 */
export interface PlannedExerciseData {
  exerciseId: string;
  exerciseName: string;
  duration?: number;
  sets?: number;
  reps?: number;
  weight?: number;
  restTime?: number;
}

/** 运动计划 */
export interface ExercisePlan {
  id: string;
  userId: string;
  name: string;
  goal: "weight_loss" | "muscle_gain" | "endurance" | "strength" | "general_fitness";
  difficulty: "beginner" | "intermediate" | "advanced";
  duration: number;
  weeklySchedule: WeeklySchedule[];
  createdDate: string;
  isActive: boolean;
}

/** 周计划 */
export interface WeeklySchedule {
  dayOfWeek: number;
  exercises: PlannedExercise[];
  restDay: boolean;
}

/** 计划运动 */
export interface PlannedExercise {
  exerciseId: string;
  exerciseName: string;
  duration?: number;
  sets?: number;
  reps?: number;
  weight?: number;
  restTime?: number;
}

/** 运动计划列表响应 */
export interface ExercisePlanListResult {
  list: ExercisePlan[];
}

/** 运动计划响应 */
export interface ExercisePlanResult {
  plan: ExercisePlan;
}

/** 推荐运动参数 */
export interface RecommendedExerciseParams {
  goal?: string;
  duration?: number;
  difficulty?: string;
}

/** 推荐运动响应 */
export interface RecommendedExerciseResult {
  list: Exercise[];
}
