import request from "@/utils/request";

const EducationAPI = {
  /**
   * 获取文章列表
   *
   * @param params 查询参数
   * @returns 文章列表
   */
  getArticles(params: ArticleQueryParams): Promise<ArticleListResult> {
    return request<ArticleListResult>({
      url: "/api/v1/health/education/articles",
      method: "GET",
      data: params,
    });
  },

  /**
   * 获取文章详情
   *
   * @param articleId 文章ID
   * @returns 文章详情
   */
  getArticleDetail(articleId: string): Promise<ArticleDetailResult> {
    return request<ArticleDetailResult>({
      url: `/api/v1/health/education/articles/${articleId}`,
      method: "GET",
    });
  },

  /**
   * 搜索文章
   *
   * @param keyword 关键词
   * @param params 查询参数
   * @returns 文章列表
   */
  searchArticles(keyword: string, params: ArticleSearchParams): Promise<ArticleListResult> {
    return request<ArticleListResult>({
      url: "/api/v1/health/education/articles/search",
      method: "GET",
      data: { keyword, ...params },
    });
  },

  /**
   * 点赞文章
   *
   * @param articleId 文章ID
   */
  likeArticle(articleId: string): Promise<void> {
    return request({
      url: `/api/v1/health/education/articles/${articleId}/like`,
      method: "POST",
    });
  },

  /**
   * 获取视频列表
   *
   * @param params 查询参数
   * @returns 视频列表
   */
  getVideos(params: VideoQueryParams): Promise<VideoListResult> {
    return request<VideoListResult>({
      url: "/api/v1/health/education/videos",
      method: "GET",
      data: params,
    });
  },

  /**
   * 获取视频详情
   *
   * @param videoId 视频ID
   * @returns 视频详情
   */
  getVideoDetail(videoId: string): Promise<VideoDetailResult> {
    return request<VideoDetailResult>({
      url: `/api/v1/health/education/videos/${videoId}`,
      method: "GET",
    });
  },

  /**
   * 搜索视频
   *
   * @param keyword 关键词
   * @param params 查询参数
   * @returns 视频列表
   */
  searchVideos(keyword: string, params: VideoSearchParams): Promise<VideoListResult> {
    return request<VideoListResult>({
      url: "/api/v1/health/education/videos/search",
      method: "GET",
      data: { keyword, ...params },
    });
  },

  /**
   * 记录视频观看
   *
   * @param videoId 视频ID
   * @param data 观看数据
   */
  recordVideoView(videoId: string, data: VideoViewData): Promise<void> {
    return request({
      url: `/api/v1/health/education/videos/${videoId}/view`,
      method: "POST",
      data: data,
      header: {
        "Content-Type": "application/json",
      },
    });
  },

  /**
   * 获取课程列表
   *
   * @param params 查询参数
   * @returns 课程列表
   */
  getCourses(params: CourseQueryParams): Promise<CourseListResult> {
    return request<CourseListResult>({
      url: "/api/v1/health/education/courses",
      method: "GET",
      data: params,
    });
  },

  /**
   * 获取课程详情
   *
   * @param courseId 课程ID
   * @returns 课程详情
   */
  getCourseDetail(courseId: string): Promise<CourseDetailResult> {
    return request<CourseDetailResult>({
      url: `/api/v1/health/education/courses/${courseId}`,
      method: "GET",
    });
  },

  /**
   * 报名课程
   *
   * @param courseId 课程ID
   */
  enrollCourse(courseId: string): Promise<void> {
    return request({
      url: `/api/v1/health/education/courses/${courseId}/enroll`,
      method: "POST",
    });
  },

  /**
   * 获取学习进度
   *
   * @param courseId 课程ID
   * @returns 学习进度
   */
  getStudyProgress(courseId: string): Promise<StudyProgressResult> {
    return request<StudyProgressResult>({
      url: `/api/v1/health/education/courses/${courseId}/progress`,
      method: "GET",
    });
  },

  /**
   * 完成课程
   *
   * @param courseId 课程ID
   * @param lessonId 课时ID
   */
  completeLesson(courseId: string, lessonId: string): Promise<void> {
    return request({
      url: `/api/v1/health/education/courses/${courseId}/lessons/${lessonId}/complete`,
      method: "POST",
    });
  },
};

export default EducationAPI;

/** 文章查询参数 */
export interface ArticleQueryParams {
  category?: string;
  difficulty?: string;
  page: number;
  pageSize: number;
}

/** 文章搜索参数 */
export interface ArticleSearchParams {
  page: number;
  pageSize: number;
}

/** 文章列表响应 */
export interface ArticleListResult {
  list: HealthArticle[];
  total: number;
  page: number;
  pageSize: number;
}

/** 文章详情响应 */
export interface ArticleDetailResult {
  article: HealthArticle;
}

/** 健康文章 */
export interface HealthArticle {
  id: string;
  title: string;
  summary: string;
  content: string;
  category: string;
  tags: string[];
  author: string;
  publishDate: string;
  readCount: number;
  likeCount: number;
  difficulty: "beginner" | "intermediate" | "advanced";
  images: string[];
  relatedArticles: string[];
}

/** 视频查询参数 */
export interface VideoQueryParams {
  category?: string;
  difficulty?: string;
  page: number;
  pageSize: number;
}

/** 视频搜索参数 */
export interface VideoSearchParams {
  page: number;
  pageSize: number;
}

/** 视频列表响应 */
export interface VideoListResult {
  list: HealthVideo[];
  total: number;
  page: number;
  pageSize: number;
}

/** 视频详情响应 */
export interface VideoDetailResult {
  video: HealthVideo;
}

/** 健康视频 */
export interface HealthVideo {
  id: string;
  title: string;
  description: string;
  category: string;
  tags: string[];
  instructor: string;
  duration: number;
  difficulty: "beginner" | "intermediate" | "advanced";
  videoUrl: string;
  thumbnailUrl: string;
  publishDate: string;
  viewCount: number;
  likeCount: number;
  relatedVideos: string[];
}

/** 视频观看数据 */
export interface VideoViewData {
  watchDuration: number;
}

/** 课程查询参数 */
export interface CourseQueryParams {
  category?: string;
  difficulty?: string;
  page: number;
  pageSize: number;
}

/** 课程列表响应 */
export interface CourseListResult {
  list: HealthCourse[];
  total: number;
  page: number;
  pageSize: number;
}

/** 课程详情响应 */
export interface CourseDetailResult {
  course: HealthCourse;
}

/** 健康课程 */
export interface HealthCourse {
  id: string;
  title: string;
  description: string;
  category: string;
  instructor: string;
  duration: number;
  lessonCount: number;
  difficulty: "beginner" | "intermediate" | "advanced";
  price: number;
  rating: number;
  enrollmentCount: number;
  lessons: CourseLesson[];
  thumbnailUrl: string;
  createdDate: string;
}

/** 课程课时 */
export interface CourseLesson {
  id: string;
  title: string;
  description: string;
  duration: number;
  videoUrl?: string;
  materials?: string[];
  quiz?: Quiz;
  order: number;
}

/** 测验 */
export interface Quiz {
  id: string;
  questions: QuizQuestion[];
  passingScore: number;
}

/** 测验问题 */
export interface QuizQuestion {
  id: string;
  question: string;
  options: string[];
  correctAnswer: number;
  explanation?: string;
}

/** 学习进度响应 */
export interface StudyProgressResult {
  progress: StudyProgress;
}

/** 学习进度 */
export interface StudyProgress {
  courseId: string;
  completedLessons: string[];
  totalLessons: number;
  progressPercentage: number;
  lastStudyDate: string;
  totalStudyTime: number;
}
