import { defineStore } from "pinia";
import { ConsultationAPI, type Doctor, type Consultation, type ChatMessage } from "@/api/health";
import { ref } from "vue";

export const useConsultationStore = defineStore("consultation", () => {
  // State
  const doctorList = ref<Doctor[]>([]);
  const selectedDoctor = ref<Doctor | null>(null);
  const currentConsultation = ref<Consultation | null>(null);
  const chatMessages = ref<ChatMessage[]>([]);
  const consultationHistory = ref<Consultation[]>([]);
  const loading = ref(false);
  const error = ref("");

  // Actions
  const fetchDoctors = async (params: { specialty?: string; isOnline?: boolean }) => {
    try {
      loading.value = true;
      error.value = "";

      const res = await ConsultationAPI.getDoctors({
        ...params,
        page: 1,
        pageSize: 20,
      });

      doctorList.value = res.list;
    } catch (err) {
      error.value = err instanceof Error ? err.message : "获取医生列表失败";
      console.error("Failed to fetch doctors:", err);
    } finally {
      loading.value = false;
    }
  };

  const selectDoctor = (doctor: Doctor) => {
    selectedDoctor.value = doctor;
  };

  const createConsultation = async (symptoms: string, type: "text" | "voice" | "video") => {
    if (!selectedDoctor.value) return;

    try {
      loading.value = true;
      error.value = "";

      const res = await ConsultationAPI.createConsultation({
        doctorId: selectedDoctor.value.id,
        symptoms,
        type,
      });

      currentConsultation.value = res.consultation;
      return res.consultation;
    } catch (err) {
      error.value = err instanceof Error ? err.message : "创建咨询失败";
      console.error("Failed to create consultation:", err);
      throw err;
    } finally {
      loading.value = false;
    }
  };

  const fetchConsultationHistory = async () => {
    try {
      loading.value = true;
      error.value = "";

      const res = await ConsultationAPI.getConsultationHistory({
        page: 1,
        pageSize: 20,
      });

      consultationHistory.value = res.list;
    } catch (err) {
      error.value = err instanceof Error ? err.message : "获取咨询历史失败";
      console.error("Failed to fetch consultation history:", err);
    } finally {
      loading.value = false;
    }
  };

  const fetchChatMessages = async (consultationId: string) => {
    try {
      loading.value = true;
      error.value = "";

      const res = await ConsultationAPI.getChatMessages(consultationId, {
        page: 1,
        pageSize: 100,
      });

      chatMessages.value = res.list;
    } catch (err) {
      error.value = err instanceof Error ? err.message : "获取聊天记录失败";
      console.error("Failed to fetch chat messages:", err);
    } finally {
      loading.value = false;
    }
  };

  const sendMessage = async (content: string, type: "text" | "image" = "text") => {
    if (!currentConsultation.value) return;

    try {
      const res = await ConsultationAPI.sendMessage({
        consultationId: currentConsultation.value.id,
        content,
        type,
      });

      chatMessages.value.push(res.message);
    } catch (err) {
      error.value = err instanceof Error ? err.message : "发送消息失败";
      console.error("Failed to send message:", err);
      throw err;
    }
  };

  const endConsultation = async (consultationId: string) => {
    try {
      await ConsultationAPI.endConsultation(consultationId);
      currentConsultation.value = null;
    } catch (err) {
      error.value = err instanceof Error ? err.message : "结束咨询失败";
      console.error("Failed to end consultation:", err);
      throw err;
    }
  };

  const rateConsultation = async (consultationId: string, rating: number, review: string) => {
    try {
      await ConsultationAPI.rateConsultation(consultationId, {
        rating,
        review,
      });
    } catch (err) {
      error.value = err instanceof Error ? err.message : "评价咨询失败";
      console.error("Failed to rate consultation:", err);
      throw err;
    }
  };

  const clearCurrentConsultation = () => {
    currentConsultation.value = null;
    chatMessages.value = [];
  };

  return {
    doctorList,
    selectedDoctor,
    currentConsultation,
    chatMessages,
    consultationHistory,
    loading,
    error,
    fetchDoctors,
    selectDoctor,
    createConsultation,
    fetchConsultationHistory,
    fetchChatMessages,
    sendMessage,
    endConsultation,
    rateConsultation,
    clearCurrentConsultation,
  };
});
