import { defineStore } from "pinia";
import { DetectionAPI, type VitalSigns, type HealthReport } from "@/api/health";
import { ref } from "vue";

export const useDetectionStore = defineStore("detection", () => {
  // State
  const vitalSignsHistory = ref<VitalSigns[]>([]);
  const healthReports = ref<HealthReport[]>([]);
  const currentHealthReport = ref<HealthReport | null>(null);
  const loading = ref(false);
  const error = ref("");

  // Actions
  const recordVitalSigns = async (data: {
    bloodPressure: { systolic: number; diastolic: number };
    heartRate: number;
    bodyTemperature: number;
    bloodOxygen: number;
    weight: number;
    height: number;
  }) => {
    try {
      loading.value = true;
      error.value = "";

      const res = await DetectionAPI.recordVitalSigns(data);
      vitalSignsHistory.value.unshift(res.vitalSigns);
    } catch (err) {
      error.value = err instanceof Error ? err.message : "记录生命体征失败";
      console.error("Failed to record vital signs:", err);
      throw err;
    } finally {
      loading.value = false;
    }
  };

  const fetchVitalSignsHistory = async () => {
    try {
      loading.value = true;
      error.value = "";

      const res = await DetectionAPI.getVitalSignsHistory({
        page: 1,
        pageSize: 30,
      });

      vitalSignsHistory.value = res.list;
    } catch (err) {
      error.value = err instanceof Error ? err.message : "获取生命体征历史失败";
      console.error("Failed to fetch vital signs history:", err);
    } finally {
      loading.value = false;
    }
  };

  const generateHealthReport = async (type: "basic" | "comprehensive" | "specialized") => {
    try {
      loading.value = true;
      error.value = "";

      const res = await DetectionAPI.generateHealthReport({ type });
      healthReports.value.unshift(res.report);
      currentHealthReport.value = res.report;
    } catch (err) {
      error.value = err instanceof Error ? err.message : "生成健康报告失败";
      console.error("Failed to generate health report:", err);
      throw err;
    } finally {
      loading.value = false;
    }
  };

  const fetchHealthReports = async () => {
    try {
      loading.value = true;
      error.value = "";

      const res = await DetectionAPI.getHealthReports({
        page: 1,
        pageSize: 10,
      });

      healthReports.value = res.list;
    } catch (err) {
      error.value = err instanceof Error ? err.message : "获取健康报告失败";
      console.error("Failed to fetch health reports:", err);
    } finally {
      loading.value = false;
    }
  };

  const fetchHealthReportDetail = async (reportId: string) => {
    try {
      loading.value = true;
      error.value = "";

      const res = await DetectionAPI.getHealthReportDetail(reportId);
      currentHealthReport.value = res.report;
    } catch (err) {
      error.value = err instanceof Error ? err.message : "获取健康报告详情失败";
      console.error("Failed to fetch health report detail:", err);
      throw err;
    } finally {
      loading.value = false;
    }
  };

  return {
    vitalSignsHistory,
    healthReports,
    currentHealthReport,
    loading,
    error,
    recordVitalSigns,
    fetchVitalSignsHistory,
    generateHealthReport,
    fetchHealthReports,
    fetchHealthReportDetail,
  };
});
