/**
 * 健康数据计算工具
 */

// 计算BMI
export const calculateBMI = (weight: number, height: number): number => {
  const heightInMeters = height / 100;
  return Number((weight / (heightInMeters * heightInMeters)).toFixed(1));
};

// BMI分类
export const getBMICategory = (bmi: number): string => {
  if (bmi < 18.5) return "偏瘦";
  if (bmi < 24) return "正常";
  if (bmi < 28) return "超重";
  return "肥胖";
};

// 计算基础代谢率 (BMR)
export const calculateBMR = (
  weight: number,
  height: number,
  age: number,
  gender: "male" | "female"
): number => {
  if (gender === "male") {
    return Math.round(88.362 + 13.397 * weight + 4.799 * height - 5.677 * age);
  } else {
    return Math.round(447.593 + 9.247 * weight + 3.098 * height - 4.33 * age);
  }
};

// 计算每日热量需求 (TDEE)
export const calculateTDEE = (bmr: number, activityLevel: string): number => {
  const activityFactors = {
    sedentary: 1.2, // 久坐
    light: 1.375, // 轻度运动
    moderate: 1.55, // 中度运动
    active: 1.725, // 重度运动
    very_active: 1.9, // 极重度运动
  };

  return Math.round(bmr * (activityFactors[activityLevel] || 1.2));
};

// 计算理想体重范围
export const calculateIdealWeightRange = (height: number): { min: number; max: number } => {
  const heightInMeters = height / 100;
  const min = Number((18.5 * heightInMeters * heightInMeters).toFixed(1));
  const max = Number((23.9 * heightInMeters * heightInMeters).toFixed(1));

  return { min, max };
};

// 计算运动消耗卡路里
export const calculateCaloriesBurned = (
  activity: string,
  weight: number,
  duration: number
): number => {
  // MET值 (代谢当量)
  const metValues: Record<string, number> = {
    walking: 3.5,
    running: 8.0,
    cycling: 6.0,
    swimming: 8.0,
    yoga: 2.5,
    strength_training: 3.0,
    basketball: 6.5,
    football: 8.0,
    tennis: 7.0,
    badminton: 5.5,
  };

  const met = metValues[activity] || 3.0;
  return Math.round(met * weight * (duration / 60));
};

// 计算心率区间
export const calculateHeartRateZones = (age: number) => {
  const maxHR = 220 - age;

  return {
    rest: { min: 60, max: 100 },
    fat_burn: { min: Math.round(maxHR * 0.6), max: Math.round(maxHR * 0.7) },
    cardio: { min: Math.round(maxHR * 0.7), max: Math.round(maxHR * 0.85) },
    peak: { min: Math.round(maxHR * 0.85), max: maxHR },
  };
};

// 计算血压分类
export const getBloodPressureCategory = (
  systolic: number,
  diastolic: number
): {
  category: string;
  level: "normal" | "elevated" | "high";
} => {
  if (systolic < 120 && diastolic < 80) {
    return { category: "正常血压", level: "normal" };
  } else if (systolic < 130 && diastolic < 80) {
    return { category: "血压偏高", level: "elevated" };
  } else if (systolic < 140 || diastolic < 90) {
    return { category: "高血压1期", level: "high" };
  } else if (systolic < 160 || diastolic < 100) {
    return { category: "高血压2期", level: "high" };
  } else {
    return { category: "高血压3期", level: "high" };
  }
};
