/**
 * 健康数据验证工具
 */

// 验证生命体征数据
export const validateVitalSigns = (data: any): { isValid: boolean; errors: string[] } => {
  const errors: string[] = [];

  // 血压验证
  if (data.bloodPressure) {
    const { systolic, diastolic } = data.bloodPressure;
    if (systolic < 70 || systolic > 250) {
      errors.push("收缩压应在70-250mmHg之间");
    }
    if (diastolic < 40 || diastolic > 150) {
      errors.push("舒张压应在40-150mmHg之间");
    }
    if (systolic <= diastolic) {
      errors.push("收缩压应大于舒张压");
    }
  }

  // 心率验证
  if (data.heartRate && (data.heartRate < 30 || data.heartRate > 220)) {
    errors.push("心率应在30-220bpm之间");
  }

  // 体温验证
  if (data.bodyTemperature && (data.bodyTemperature < 30 || data.bodyTemperature > 45)) {
    errors.push("体温应在30-45°C之间");
  }

  // 血氧验证
  if (data.bloodOxygen && (data.bloodOxygen < 70 || data.bloodOxygen > 100)) {
    errors.push("血氧饱和度应在70-100%之间");
  }

  // 体重验证
  if (data.weight && (data.weight < 20 || data.weight > 300)) {
    errors.push("体重应在20-300kg之间");
  }

  // 身高验证
  if (data.height && (data.height < 50 || data.height > 250)) {
    errors.push("身高应在50-250cm之间");
  }

  return {
    isValid: errors.length === 0,
    errors,
  };
};

// 验证血糖数据
export const validateBloodSugar = (
  value: number,
  mealRelation: string
): {
  isValid: boolean;
  level: "normal" | "low" | "high";
  message: string;
} => {
  let isValid = true;
  let level: "normal" | "low" | "high" = "normal";
  let message = "";

  if (value < 2 || value > 30) {
    isValid = false;
    message = "血糖值异常，请重新测量";
    return { isValid, level, message };
  }

  switch (mealRelation) {
    case "fasting":
      if (value < 3.9) {
        level = "low";
        message = "空腹血糖偏低";
      } else if (value > 6.1) {
        level = "high";
        message = "空腹血糖偏高";
      } else {
        message = "空腹血糖正常";
      }
      break;
    case "after_meal":
      if (value < 3.9) {
        level = "low";
        message = "餐后血糖偏低";
      } else if (value > 11.1) {
        level = "high";
        message = "餐后血糖偏高";
      } else {
        message = "餐后血糖正常";
      }
      break;
    default:
      if (value < 3.9) {
        level = "low";
        message = "血糖偏低";
      } else if (value > 11.1) {
        level = "high";
        message = "血糖偏高";
      } else {
        message = "血糖正常";
      }
  }

  return { isValid, level, message };
};

// 验证药物信息
export const validateMedication = (medication: any): { isValid: boolean; errors: string[] } => {
  const errors: string[] = [];

  if (!medication.name || medication.name.trim() === "") {
    errors.push("药物名称不能为空");
  }

  if (!medication.dosage || medication.dosage.trim() === "") {
    errors.push("用药剂量不能为空");
  }

  if (!medication.frequency || medication.frequency.trim() === "") {
    errors.push("用药频率不能为空");
  }

  if (!medication.startDate) {
    errors.push("开始用药日期不能为空");
  }

  if (medication.endDate && new Date(medication.endDate) <= new Date(medication.startDate)) {
    errors.push("结束日期应晚于开始日期");
  }

  return {
    isValid: errors.length === 0,
    errors,
  };
};
